---
title: MySqlBulkLoader
---

# MySqlBulkLoader class

[`MySqlBulkLoader`](../MySqlBulkLoaderType/) lets you efficiently load a MySQL Server Table with data from a CSV or TSV file or Stream.

Example code:

```csharp
using var connection = new MySqlConnection("...;AllowLoadLocalInfile=True");
await connection.OpenAsync();
var bulkLoader = new MySqlBulkLoader(connection)
{
	FileName = @"C:\Path\To\file.csv",
	TableName = "destination",
	CharacterSet = "UTF8",
	NumberOfLinesToSkip = 1,
	FieldTerminator = ",",
	FieldQuotationCharacter = '"',
	FieldQuotationOptional = true,
	Local = true,
}
var rowCount = await bulkLoader.LoadAsync();
```

```csharp
public sealed class MySqlBulkLoader
```

## Public Members

| name | description |
| --- | --- |
| [MySqlBulkLoader](../MySqlBulkLoader/MySqlBulkLoader/)(…) | Initializes a new instance of the [`MySqlBulkLoader`](../MySqlBulkLoaderType/) class with the specified [`MySqlConnection`](../MySqlConnectionType/). |
| [CharacterSet](../MySqlBulkLoader/CharacterSet/) { get; set; } | (Optional) The character set of the source data. By default, the database's character set is used. |
| [Columns](../MySqlBulkLoader/Columns/) { get; } | (Optional) A list of the column names in the destination table that should be filled with data from the input file. |
| [ConflictOption](../MySqlBulkLoader/ConflictOption/) { get; set; } | A [`MySqlBulkLoaderConflictOption`](../MySqlBulkLoaderConflictOptionType/) value that specifies how conflicts are resolved (default None). |
| [Connection](../MySqlBulkLoader/Connection/) { get; set; } | The [`MySqlConnection`](../MySqlConnectionType/) to use. |
| [EscapeCharacter](../MySqlBulkLoader/EscapeCharacter/) { get; set; } | (Optional) The character used to escape instances of [`FieldQuotationCharacter`](../MySqlBulkLoader/FieldQuotationCharacter/) within field values. |
| [Expressions](../MySqlBulkLoader/Expressions/) { get; } | (Optional) A list of expressions used to set field values from the columns in the source data. |
| [FieldQuotationCharacter](../MySqlBulkLoader/FieldQuotationCharacter/) { get; set; } | (Optional) The character used to enclose fields in the source data. |
| [FieldQuotationOptional](../MySqlBulkLoader/FieldQuotationOptional/) { get; set; } | Whether quoting fields is optional (default `false`). |
| [FieldTerminator](../MySqlBulkLoader/FieldTerminator/) { get; set; } | (Optional) The string fields are terminated with. |
| [FileName](../MySqlBulkLoader/FileName/) { get; set; } | The name of the local (if [`Local`](../MySqlBulkLoader/Local/) is `true`) or remote (otherwise) file to load. Either this or [`SourceStream`](../MySqlBulkLoader/SourceStream/) must be set. |
| [LinePrefix](../MySqlBulkLoader/LinePrefix/) { get; set; } | (Optional) A prefix in each line that should be skipped when loading. |
| [LineTerminator](../MySqlBulkLoader/LineTerminator/) { get; set; } | (Optional) The string lines are terminated with. |
| [Local](../MySqlBulkLoader/Local/) { get; set; } | Whether a local file is being used (default `true`). |
| [NumberOfLinesToSkip](../MySqlBulkLoader/NumberOfLinesToSkip/) { get; set; } | The number of lines to skip at the beginning of the file (default `0`). |
| [Priority](../MySqlBulkLoader/Priority/) { get; set; } | A [`MySqlBulkLoaderPriority`](../MySqlBulkLoaderPriorityType/) giving the priority to load with (default None). |
| [SourceStream](../MySqlBulkLoader/SourceStream/) { get; set; } | A Stream containing the data to load. Either this or [`FileName`](../MySqlBulkLoader/FileName/) must be set. The [`Local`](../MySqlBulkLoader/Local/) property must be `true` if this is set. |
| [TableName](../MySqlBulkLoader/TableName/) { get; set; } | The name of the table to load into. If this is a reserved word or contains spaces, it must be quoted. |
| [Timeout](../MySqlBulkLoader/Timeout/) { get; set; } | The timeout (in milliseconds) to use. |
| [Load](../MySqlBulkLoader/Load/)() | Loads all data in the source file or stream into the destination table. |
| [LoadAsync](../MySqlBulkLoader/LoadAsync/)() | Asynchronously loads all data in the source file or stream into the destination table. |
| [LoadAsync](../MySqlBulkLoader/LoadAsync/)(…) | Asynchronously loads all data in the source file or stream into the destination table. |

## Remarks

Due to [security features](https://mysqlconnector.net/troubleshooting/load-data-local-infile/) in MySQL Server, the connection string must have `AllowLoadLocalInfile=true` in order to use a local source.

## See Also

* namespace [MySqlConnector](../../MySqlConnectorNamespace/)
* assembly [MySqlConnector](../../MySqlConnectorAssembly/)

<!-- DO NOT EDIT: generated by xmldocmd for MySqlConnector.dll -->
